@@ -256,6 +256,9 @@ gpm_hal_handle_error (guint ret, GError *error, const char *method)
 		if (g_error_matches (error, DBUS_GERROR, DBUS_GERROR_NO_REPLY)) {
 			gpm_debug ("DBUS timed out, but recovering");
 			retval = TRUE;
+		} else if (g_error_matches (error, DBUS_GERROR, DBUS_GERROR_REMOTE_EXCEPTION)) {
+			gpm_debug ("Remote exception, recovering");
+			retval = TRUE;
 		} else {
 			gpm_warning ("%s failed\n(%s)",
 				     method,
@@ -408,7 +411,6 @@ gpm_hal_enable_power_save (GpmHal *hal, gboolean enable)
 		return FALSE;
 	}
 
-
 	gpm_debug ("Doing SetPowerSave (%i)", enable);
 	hal_proxy = dbus_g_proxy_new_for_name (hal->priv->connection,
 					       HAL_DBUS_SERVICE,
@@ -1192,6 +1194,32 @@ gpm_hal_new_capability_cb (DBusGProxy *proxy,
 	g_signal_emit (hal, signals [NEW_CAPABILITY], 0, udi, capability);
 }
 
+/**
+ * remove_device_property_modified_in_hash:
+ *
+ * @udi: The HAL UDI
+ *
+ * HashFunc so we can remove all the device-propery-modified devices
+ */
+static void
+remove_device_property_modified_in_hash (const char *udi, gpointer value, GpmHal *hal)
+{
+	gpm_hal_device_remove_propery_modified (hal, udi);
+}
+
+/**
+ * remove_device_condition_in_hash:
+ *
+ * @udi: The HAL UDI
+ *
+ * HashFunc so we can remove all the device-condition devices
+ */
+static void
+remove_device_condition_in_hash (const char *udi, gpointer value, GpmHal *hal)
+{
+	gpm_hal_device_remove_condition (hal, udi);
+}
+
 /**
  * gpm_hal_connect:
  *
@@ -1280,6 +1308,11 @@ gpm_hal_disconnect (GpmHal *hal)
 	dbus_g_proxy_disconnect_signal (hal->priv->manager_proxy, "NewCapability",
 					G_CALLBACK (gpm_hal_new_capability_cb), hal);
 
+        g_hash_table_foreach (hal->priv->watch_device_property_modified,
+					(GHFunc) remove_device_property_modified_in_hash, hal);
+        g_hash_table_foreach (hal->priv->watch_device_condition,
+		 			(GHFunc) remove_device_condition_in_hash, hal);
+
 	g_object_unref (hal->priv->manager_proxy);
 	hal->priv->manager_proxy = NULL;
 
@@ -1355,32 +1388,6 @@ gpm_hal_init (GpmHal *hal)
 	gpm_hal_connect (hal);
 }
 
-/**
- * remove_device_property_modified_in_hash:
- *
- * @udi: The HAL UDI
- *
- * HashFunc so we can remove all the device-propery-modified devices
- */
-static void
-remove_device_property_modified_in_hash (const char *udi, gpointer value, GpmHal *hal)
-{
-	gpm_hal_device_remove_propery_modified (hal, udi);
-}
-
-/**
- * remove_device_condition_in_hash:
- *
- * @udi: The HAL UDI
- *
- * HashFunc so we can remove all the device-condition devices
- */
-static void
-remove_device_condition_in_hash (const char *udi, gpointer value, GpmHal *hal)
-{
-	gpm_hal_device_remove_condition (hal, udi);
-}
-
 /**
  * gpm_hal_finalize:
  * @object: This hal class instance
