@@ -455,15 +455,15 @@ gpm_power_kind_to_string (GpmPowerKind battery_kind)
 	if (battery_kind == GPM_POWER_KIND_PRIMARY) {
  		str = "primary";
 	} else if (battery_kind == GPM_POWER_KIND_UPS) {
- 		str = _("ups");
+ 		str = "ups";
 	} else if (battery_kind == GPM_POWER_KIND_MOUSE) {
- 		str = _("mouse");
+ 		str = "mouse";
 	} else if (battery_kind == GPM_POWER_KIND_KEYBOARD) {
- 		str = _("keyboard");
+ 		str = "keyboard";
 	} else if (battery_kind == GPM_POWER_KIND_PDA) {
- 		str = _("pda");
+ 		str = "pda";
  	} else {
- 		str = _("unknown");
+ 		str = "unknown";
 	}
 	return str;
 }
@@ -878,6 +878,8 @@ gpm_power_get_icon_from_status (GpmPowerStatus *device_status,
 	char	   *filename = NULL;
 	const char *prefix;
 
+	gpm_debug ("getting kind %i", kind);
+
 	/* TODO: icons need to be renamed from -battery- to -primary- */
 	prefix = gpm_power_kind_to_string (kind);
 
@@ -966,22 +968,6 @@ battery_kind_cache_update (GpmPower		 *power,
 		type_status->is_charging = FALSE;
 	}
 
-	/* If the primary battery is neither charging nor discharging, and
-	 * the charge is low the battery is most likely broken.
-	 * In this case, we'll use the ac_adaptor to determine whether it's
-	 * charging or not. */
-	if (entry->battery_kind == GPM_POWER_KIND_PRIMARY &&
-	    (! type_status->is_charging) && (! type_status->is_discharging) &&
-	    type_status->percentage_charge > 0 &&
-	    type_status->percentage_charge < GPM_POWER_MIN_CHARGED_PERCENTAGE) {
-		gboolean on_ac;
-		on_ac = gpm_hal_is_on_ac (power->priv->hal);
-		gpm_debug ("Battery is neither charging nor discharging, "
-			   "using ac_adaptor value %i", on_ac);
-		type_status->is_charging = on_ac;
-		type_status->is_discharging = !(on_ac);
-	}
-
 	gpm_debug ("%i devices of type %s", num_present, gpm_power_kind_to_localised_string (entry->battery_kind));
 
 	/* Perform following calculations with floating point otherwise we might
@@ -999,6 +985,22 @@ battery_kind_cache_update (GpmPower		 *power,
 		}
 		type_status->percentage_charge = pc;
 	}
+
+	/* If the primary battery is neither charging nor discharging, and
+	 * the charge is low the battery is most likely broken.
+	 * In this case, we'll use the ac_adaptor to determine whether it's
+	 * charging or not. */
+	if (entry->battery_kind == GPM_POWER_KIND_PRIMARY &&
+	    type_status->is_charging == FALSE &&
+	    type_status->is_discharging == FALSE &&
+	    type_status->percentage_charge > 0 &&
+	    type_status->percentage_charge < GPM_POWER_MIN_CHARGED_PERCENTAGE) {
+		gpm_debug ("Battery is neither charging nor discharging, "
+			   "using ac_adaptor value %i", power->priv->on_ac);
+		type_status->is_charging = power->priv->on_ac;
+		type_status->is_discharging = !(power->priv->on_ac);
+	}
+
 	/* We only do the "better" remaining time algorithm if the battery has rate,
 	   i.e not a UPS, which gives it's own battery.remaining_time but has no rate */
 	if (type_status->charge_rate_smoothed > 0) {
