@@ -370,6 +370,8 @@ gpm_tray_icon_show_about_cb (GtkAction   *action,
 			       "translator-credits", translators,
 			       "logo-icon-name", GPM_STOCK_APP_ICON,
 			       NULL);
+
+	g_free (license_trans);
 }
 
 #if USE_EGGTRAYICON
@@ -677,6 +679,10 @@ gpm_tray_icon_init (GpmTrayIcon *icon)
 	icon->priv->show_notifications = TRUE;
 	icon->priv->stock_id = g_strdup ("about-blank");
 
+#ifdef HAVE_LIBNOTIFY
+	icon->priv->notify = NULL;
+#endif
+
 	icon->priv->ui_manager = gtk_ui_manager_new ();
 
 #if USE_EGGTRAYICON
@@ -784,19 +790,28 @@ libnotify_event (GpmTrayIcon    *icon,
 		 const char	*msgicon,
 		 GpmNotifyLevel	 urgency)
 {
+	GtkWidget *point = NULL;
+
 	if (icon->priv->notify != NULL) {
 		notify_notification_close (icon->priv->notify, NULL);
 	}
 
 	/* Point to the center of the icon as per the GNOME HIG, #338638 */
-	GtkWidget *point = NULL;
 #if USE_EGGTRAYICON
 	if (icon->priv->is_visible) {
 		point = icon->priv->image;
 	}
-#endif
 	icon->priv->notify = notify_notification_new (title, content,
 						      msgicon, point);
+/* DISTROS: If you've patched your libnotify 0.4.2 package you can remove this check */
+#elif HAVE_LIBNOTIFY_NEW
+	icon->priv->notify = notify_notification_new_with_status_icon (title, content,
+								       msgicon, icon->priv->status_icon);
+#else
+	/* we can't point because of a bug in libnotify. Need dependency on 0.4.3 */
+	icon->priv->notify = notify_notification_new (title, content,
+						      msgicon, NULL);
+#endif
 
 	notify_notification_set_timeout (icon->priv->notify, timeout * 1000);
 
@@ -854,7 +869,7 @@ libnotify_event (GpmTrayIcon    *icon,
 						     "<span size='larger'><b>%s</b></span>",
 						     GPM_NAME);
 
-	gtk_message_dialog_format_content_markup (GTK_MESSAGE_DIALOG (dialog), content);
+	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog), content);
 
 	g_signal_connect_swapped (dialog,
 				  "response",
